@@ -137,7 +137,7 @@ class CommonBrowserView(BrowserView):
             item = brains[0]
         
         for tag in item.Subject:
-            classes.append("tag_%s"%tag)
+            classes.append("tag_%s"%tag.replace(" ", "_"))
         
         return " ".join(classes)
     
